@@ -339,18 +339,11 @@ class FormWithActsLikeFormForTest < FormWithTest
     super
   end
 
-  def test_form_with_requires_arguments
-    error = assert_raises(ArgumentError) do
-      form_for(nil, html: { id: "create-post" }) do
+  def test_form_with_when_given_nil_model_argument
+    assert_deprecated(ActionView.deprecator) do
+      form_with(model: nil) do
       end
     end
-    assert_equal "First argument in form cannot contain nil or be empty", error.message
-
-    error = assert_raises(ArgumentError) do
-      form_for([nil, nil], html: { id: "create-post" }) do
-      end
-    end
-    assert_equal "First argument in form cannot contain nil or be empty", error.message
   end
 
   def test_form_with
