@@ -32,6 +32,16 @@ class AttributeMethodsTest < ActiveRecord::TestCase
     ActiveRecord::Base.send(:attribute_method_patterns).concat(@old_matchers)
   end
 
+  test "#id_value alias is defined if id column exist" do
+    new_topic_model = Class.new(ActiveRecord::Base) do
+      self.table_name = "topics"
+    end
+
+    new_topic_model.define_attribute_methods
+    assert_includes new_topic_model.attribute_names, "id"
+    assert_includes new_topic_model.attribute_aliases, "id_value"
+  end
+
   test "aliasing `id` attribute allows reading the column value" do
     topic = Topic.create(id: 123_456, title: "title").becomes(TitlePrimaryKeyTopic)
 
@@ -131,8 +141,10 @@ class AttributeMethodsTest < ActiveRecord::TestCase
 
   test "caching a nil primary key" do
     klass = Class.new(Minimalistic)
-    assert_called(klass, :reset_primary_key, returns: nil) do
-      2.times { klass.primary_key }
+    klass.primary_key # warm once
+
+    assert_not_called(klass, :reset_primary_key) do
+      klass.primary_key
     end
   end
 
@@ -430,9 +442,9 @@ class AttributeMethodsTest < ActiveRecord::TestCase
   test "read_attribute when true" do
     topic = topics(:first)
     topic.approved = true
-    assert topic.approved?, "approved should be true"
+    assert_predicate topic, :approved?, "approved should be true"
     topic.approved = "true"
-    assert topic.approved?, "approved should be true"
+    assert_predicate topic, :approved?, "approved should be true"
   end
 
   test "boolean attributes writing and reading" do
@@ -444,10 +456,10 @@ class AttributeMethodsTest < ActiveRecord::TestCase
     assert_not topic.approved?, "approved should be false"
 
     topic.approved = "true"
-    assert topic.approved?, "approved should be true"
+    assert_predicate topic, :approved?, "approved should be true"
 
     topic.approved = "true"
-    assert topic.approved?, "approved should be true"
+    assert_predicate topic, :approved?, "approved should be true"
   end
 
   test "overridden write_attribute" do
@@ -680,23 +692,13 @@ class AttributeMethodsTest < ActiveRecord::TestCase
 
   test "typecast attribute from select to false" do
     Topic.create(title: "Budget")
-    # Oracle does not support boolean expressions in SELECT.
-    if current_adapter?(:OracleAdapter)
-      topic = Topic.all.merge!(select: "topics.*, 0 as is_test").first
-    else
-      topic = Topic.all.merge!(select: "topics.*, 1=2 as is_test").first
-    end
+    topic = Topic.all.merge!(select: "topics.*, 1=2 as is_test").first
     assert_not_predicate topic, :is_test?
   end
 
   test "typecast attribute from select to true" do
     Topic.create(title: "Budget")
-    # Oracle does not support boolean expressions in SELECT.
-    if current_adapter?(:OracleAdapter)
-      topic = Topic.all.merge!(select: "topics.*, 1 as is_test").first
-    else
-      topic = Topic.all.merge!(select: "topics.*, 2=2 as is_test").first
-    end
+    topic = Topic.all.merge!(select: "topics.*, 2=2 as is_test").first
     assert_predicate topic, :is_test?
   end
 
@@ -1071,54 +1073,6 @@ class AttributeMethodsTest < ActiveRecord::TestCase
     assert_nothing_raised { klass.define_attribute_method("bar") }
   end
 
-  test "#method_missing define methods on the fly in a thread safe way" do
-    topic_class = Class.new(ActiveRecord::Base) do
-      self.table_name = "topics"
-    end
-
-    topic = topic_class.new(title: "New topic")
-    topic_class.undefine_attribute_methods
-    def topic.method_missing(...)
-      sleep 0.1 # required to cause a race condition
-      super
-    end
-
-    threads = 5.times.map do
-      Thread.new do
-        assert_equal "New topic", topic.title
-      end
-    end
-    threads.each(&:join)
-  ensure
-    threads&.each(&:kill)
-  end
-
-  test "#method_missing define methods on the fly in a thread safe way, even when decorated" do
-    topic_class = Class.new(ActiveRecord::Base) do
-      self.table_name = "topics"
-
-      def title
-        "title:#{super}"
-      end
-    end
-
-    topic = topic_class.new(title: "New topic")
-    topic_class.undefine_attribute_methods
-    def topic.method_missing(...)
-      sleep 0.1 # required to cause a race condition
-      super
-    end
-
-    threads = 5.times.map do
-      Thread.new do
-        assert_equal "title:New topic", topic.title
-      end
-    end
-    threads.each(&:join)
-  ensure
-    threads&.each(&:kill)
-  end
-
   test "read_attribute with nil should not asplode" do
     assert_nil Topic.new.read_attribute(nil)
   end
@@ -1291,57 +1245,39 @@ class AttributeMethodsTest < ActiveRecord::TestCase
     assert_equal([nil, "foo"], second_model_object.subject_change)
   end
 
-  ClassWithDeprecatedAliasAttributeBehavior = Class.new(ActiveRecord::Base) do
-    self.table_name = "topics"
-    alias_attribute :subject, :title
+  test "#alias_attribute with an overridden original method does not use the overridden original method" do
+    class_with_deprecated_alias_attribute_behavior = Class.new(ActiveRecord::Base) do
+      self.table_name = "topics"
+      alias_attribute :subject, :title
 
-    def title_was
-      "overridden_title_was"
+      def title_was
+        "overridden_title_was"
+      end
     end
-  end
 
-  test "#alias_attribute with an overridden original method issues a deprecation" do
-    message = <<~MESSAGE.gsub("\n", " ")
-      AttributeMethodsTest::ClassWithDeprecatedAliasAttributeBehavior model aliases
-      `title` and has a method called `title_was` defined.
-      Starting in Rails 7.2 `subject_was` will not be calling `title_was` anymore.
-      You may want to additionally define `subject_was` to preserve the current behavior.
-    MESSAGE
-
-    obj = assert_deprecated(message, ActiveRecord.deprecator) do
-      ClassWithDeprecatedAliasAttributeBehavior.new
-    end
+    obj = class_with_deprecated_alias_attribute_behavior.new
     obj.title = "hey"
     assert_equal("hey", obj.subject)
-    assert_equal("overridden_title_was", obj.subject_was)
+    assert_nil(obj.subject_was)
   end
 
-  TitleWasOverride = Module.new do
-    def title_was
-      "overridden_title_was"
+  test "#alias_attribute with an overridden original method from a module does not use the overridden original method" do
+    title_was_override = Module.new do
+      def title_was
+        "overridden_title_was"
+      end
     end
-  end
 
-  ClassWithDeprecatedAliasAttributeBehaviorFromModule = Class.new(ActiveRecord::Base) do
-    self.table_name = "topics"
-    include TitleWasOverride
-    alias_attribute :subject, :title
-  end
-
-  test "#alias_attribute with an overridden original method from a module issues a deprecation" do
-    message = <<~MESSAGE.gsub("\n", " ")
-      AttributeMethodsTest::ClassWithDeprecatedAliasAttributeBehaviorFromModule model aliases
-      `title` and has a method called `title_was` defined.
-      Starting in Rails 7.2 `subject_was` will not be calling `title_was` anymore.
-      You may want to additionally define `subject_was` to preserve the current behavior.
-    MESSAGE
-
-    obj = assert_deprecated(message, ActiveRecord.deprecator) do
-      ClassWithDeprecatedAliasAttributeBehaviorFromModule.new
+    class_with_deprecated_alias_attribute_behavior_from_module = Class.new(ActiveRecord::Base) do
+      self.table_name = "topics"
+      include title_was_override
+      alias_attribute :subject, :title
     end
+
+    obj = class_with_deprecated_alias_attribute_behavior_from_module.new
     obj.title = "hey"
     assert_equal("hey", obj.subject)
-    assert_equal("overridden_title_was", obj.subject_was)
+    assert_nil(obj.subject_was)
   end
 
   ClassWithDeprecatedAliasAttributeBehaviorResolved = Class.new(ActiveRecord::Base) do
@@ -1357,22 +1293,17 @@ class AttributeMethodsTest < ActiveRecord::TestCase
     end
   end
 
-  class ChildWithDeprecatedBehaviorResolved < ClassWithDeprecatedAliasAttributeBehaviorResolved
-  end
-
-  test "#alias_attribute with an overridden original method along with an overridden alias method doesn't issue a deprecation" do
-    obj = assert_not_deprecated(ActiveRecord.deprecator) do
-      ClassWithDeprecatedAliasAttributeBehaviorResolved.new
-    end
+  test "#alias_attribute with an overridden original method along with an overridden alias method uses the overridden alias method" do
+    obj = ClassWithDeprecatedAliasAttributeBehaviorResolved.new
     obj.title = "hey"
     assert_equal("hey", obj.subject)
     assert_equal("overridden_subject_was", obj.subject_was)
   end
 
-  test "#alias_attribute with an overridden original method along with an overridden alias method in a parent class doesn't issue a deprecation" do
-    obj = assert_not_deprecated(ActiveRecord.deprecator) do
-      ChildWithDeprecatedBehaviorResolved.new
-    end
+  test "#alias_attribute with an overridden original method along with an overridden alias method in a parent class uses the overridden alias method" do
+    child_with_deprecated_behavior_resolved = Class.new(ClassWithDeprecatedAliasAttributeBehaviorResolved)
+
+    obj = child_with_deprecated_behavior_resolved.new
     obj.title = "hey"
     assert_equal("hey", obj.subject)
     assert_equal("overridden_subject_was", obj.subject_was)
@@ -1412,91 +1343,121 @@ class AttributeMethodsTest < ActiveRecord::TestCase
     assert_equal 123_456, object.id_value
   end
 
-  ClassWithGeneratedAttributeMethodTarget = Class.new(ActiveRecord::Base) do
-    self.table_name = "topics"
-    alias_attribute :saved_title, :title_in_database
-  end
+  test "#alias_attribute with an _in_database method issues raises an error" do
+    class_with_generated_attribute_method_target = Class.new(ActiveRecord::Base) do
+      def self.name
+        "ClassWithGeneratedAttributeMethodTarget"
+      end
 
-  test "#alias_attribute with an _in_database method issues a deprecation warning" do
-    message = <<~MESSAGE.gsub("\n", " ")
-      AttributeMethodsTest::ClassWithGeneratedAttributeMethodTarget model aliases
+      self.table_name = "topics"
+
+      alias_attribute :saved_title, :title_in_database
+    end
+
+    message = <<~MESSAGE.squish
+      ClassWithGeneratedAttributeMethodTarget model aliases
       `title_in_database`, but `title_in_database` is not an attribute.
-      Starting in Rails 7.2, alias_attribute with non-attribute targets will raise.
       Use `alias_method :saved_title, :title_in_database` or define the method manually.
     MESSAGE
 
-    obj = assert_deprecated(message, ActiveRecord.deprecator) do
-      ClassWithGeneratedAttributeMethodTarget.new
+    error = assert_raises(ArgumentError) do
+      class_with_generated_attribute_method_target.new
     end
-    obj.title = "A river runs through it"
-    assert_nil obj.saved_title
-    obj.save
-    assert_equal "A river runs through it", obj.saved_title
+
+    assert_equal message, error.message
   end
 
-  ClassWithEnumMethodTarget = Class.new(ActiveRecord::Base) do
-    self.table_name = "books"
+  test "#alias_attribute with enum method raises an error" do
+    class_with_enum_method_target = Class.new(ActiveRecord::Base) do
+      def self.name
+        "ClassWithEnumMethodTarget"
+      end
 
-    attribute :status, :string
-    enum status: {
-      pending: "0",
-      completed: "1",
-    }
-    alias_attribute :is_pending?, :pending?
-  end
+      self.table_name = "books"
 
-  test "#alias_attribute with enum method issues a deprecation warning" do
-    message = <<~MESSAGE.gsub("\n", " ")
-    AttributeMethodsTest::ClassWithEnumMethodTarget model aliases `pending?`, but `pending?` is not an attribute. Starting in Rails 7.2, alias_attribute with non-attribute targets will raise. Use `alias_method :is_pending?, :pending?` or define the method manually.
+      attribute :status, :string
+
+      enum :status, {
+        pending: "0",
+        completed: "1",
+      }
+      alias_attribute :is_pending?, :pending?
+    end
+
+    message = <<~MESSAGE.squish
+      ClassWithEnumMethodTarget model aliases `pending?`, but `pending?` is not an attribute. Use `alias_method :is_pending?, :pending?` or define the method manually.
     MESSAGE
 
-    obj = assert_deprecated(message, ActiveRecord.deprecator) do
-      ClassWithEnumMethodTarget.new
+    error = assert_raises(ArgumentError) do
+      class_with_enum_method_target.new
     end
-    obj.status = "pending"
-    assert_predicate obj, :pending?
-    assert_predicate obj, :is_pending?
+    assert_equal message, error.message
   end
 
-  ClassWithAssociationTarget = Class.new(ActiveRecord::Base) do
-    self.table_name = "books"
-    belongs_to :author
+  test "#alias_attribute with an association method raises an error" do
+    class_with_association_target = Class.new(ActiveRecord::Base) do
+      def self.name
+        "ClassWithAssociationTarget"
+      end
 
-    alias_attribute :written_by, :author
-  end
+      self.table_name = "books"
 
-  test "#alias_attribute with an association method issues a deprecation warning" do
-    message = <<~MESSAGE.gsub("\n", " ")
-    AttributeMethodsTest::ClassWithAssociationTarget model aliases `author`, but `author` is not an attribute. Starting in Rails 7.2, alias_attribute with non-attribute targets will raise. Use `alias_method :written_by, :author` or define the method manually.
+      belongs_to :author
+
+      alias_attribute :written_by, :author
+    end
+
+    message = <<~MESSAGE.squish
+      ClassWithAssociationTarget model aliases `author`, but `author` is not an attribute. Use `alias_method :written_by, :author` or define the method manually.
     MESSAGE
 
-    obj = assert_deprecated(message, ActiveRecord.deprecator) do
-      ClassWithAssociationTarget.new
+    error = assert_raises(ArgumentError) do
+      class_with_association_target.new
     end
-    obj.author = Author.new(name: "Octavia E. Butler")
-    assert_equal "Octavia E. Butler", obj.written_by.name
+    assert_equal message, error.message
   end
 
-  ClassWithAliasedManuallyDefinedMethod = Class.new(ActiveRecord::Base) do
-    self.table_name = "books"
-    alias_attribute :print, :publish
-
-    def publish
-      "Publishing!"
+  test "#alias_attribute method on a STI class is available on subclasses" do
+    superclass = Class.new(ActiveRecord::Base) do
+      self.table_name = "comments"
+      alias_attribute :text, :body
     end
+
+    subclass = Class.new(superclass) do
+      self.abstract_class = true
+    end
+
+    subsubclass = Class.new(subclass)
+
+    comment = subsubclass.build(body: "Text")
+    assert_equal "Text", comment.text
   end
 
-  test "#alias_attribute with a manually defined method issues a deprecation warning" do
-    message = <<~MESSAGE.gsub("\n", " ")
-      AttributeMethodsTest::ClassWithAliasedManuallyDefinedMethod model aliases `publish`,
-      but `publish` is not an attribute.
-      Starting in Rails 7.2, alias_attribute with non-attribute targets will raise.
+
+  test "#alias_attribute with a manually defined method raises an error" do
+    class_with_aliased_manually_defined_method = Class.new(ActiveRecord::Base) do
+      def self.name
+        "ClassWithAliasedManuallyDefinedMethod"
+      end
+
+      self.table_name = "books"
+
+      alias_attribute :print, :publish
+
+      def publish
+        "Publishing!"
+      end
+    end
+
+    message = <<~MESSAGE.squish
+      ClassWithAliasedManuallyDefinedMethod model aliases `publish`, but `publish` is not an attribute.
       Use `alias_method :print, :publish` or define the method manually.
     MESSAGE
 
-    assert_deprecated(message, ActiveRecord.deprecator) do
-      ClassWithAliasedManuallyDefinedMethod.new
+    error = assert_raises(ArgumentError) do
+      class_with_aliased_manually_defined_method.new
     end
+    assert_equal message, error.message
   end
 
   private
